#!/usr/bin/env bash
set -e
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

source $(pwd)/config/configuration
source /deployment/deploy/helpers/run_command.sh
source /deployment/deploy/helpers/print_line.sh

export SERVICE_NAME=$( echo $SERVICE_NAME | tr "." _ )

IMAGE_TAG=${IMAGE_TAG:-"artifactory-pub.bit9.local:5000/cbd/${SERVICE_NAME}"}

printp "BUILDING IMAGE"

DOCKER_VARS=
DOCKER_ARGS=

if [ -f $(pwd)/hooks/pre_build_hook.sh ]; then
    . $(pwd)/hooks/pre_build_hook.sh
fi

if [ -f $(pwd)/config/docker_vars ]; then
    DOCKER_VARS=$(eval echo -e `<$(pwd)/config/docker_vars`)
    DOCKER_ARGS=$(run_deploy_command build_docker_vars $DOCKER_VARS)
fi

export PUBHOST="$(cat /etc/hosts | grep 'artifactory-pub.bit9.local')"
if [ ! -z "${PUBHOST}" ]; then
   export ADD_HOST='--add-host=artifactory-pub.bit9.local:10.205.101.19'
fi

docker build -t $SERVICE_NAME \
       $DOCKER_ARGS \
       -f $(pwd)/docker/Dockerfile \
       --pull \
       ${ADD_HOST} $(pwd)
REPO_TAG=${IMAGE_TAG}
if [[ "$REPO_TAG" != *":"* ]]; then
  REPO_TAG=${IMAGE_TAG}:${LABEL_TAG_PREFIX}latest
fi
docker tag $SERVICE_NAME:latest $REPO_TAG
docker rmi $SERVICE_NAME:latest

if [ -f $(pwd)/hooks/post_build_hook.sh ]; then
    $(pwd)/hooks/post_build_hook.sh
fi
