#!/usr/bin/env bash
set -e
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
source /deployment/deploy/helpers/aws_keys.sh
source $(pwd)/config/configuration
source /deployment/deploy/helpers/run_command.sh
source /deployment/deploy/helpers/print_line.sh

ARTIFACTORY_URL="artifactory-pub.bit9.local"
DOCKER_USER=${DOCKER_USER?user needs to be specified}
DOCKER_PASSWORD=${DOCKER_PASSWORD?password needs to be specified}
DOCKER_REGISTRY=${DOCKER_REGISTRY?registry needs to be specified}
PURGE_STRATEGY_NEVER=${PURGE_STRATEGY_NEVER:-false}

printp "LOGGING IN"
docker login -u ${DOCKER_USER} -p ${DOCKER_PASSWORD} ${DOCKER_REGISTRY}

printp "PUSHING IMAGE"
IMAGE_TAG=${IMAGE_TAG:-"artifactory-pub.bit9.local:5000/cbd/${SERVICE_NAME}:latest"}
REPO_TAG=${IMAGE_TAG}
if [[ "$REPO_TAG" != *":"* ]]; then
  REPO_TAG=${IMAGE_TAG}:${LABEL_TAG_PREFIX}latest
fi
docker push $REPO_TAG
export IMAGE_DIGEST=$(docker image inspect --format "{{.RepoDigests}}" $REPO_TAG | tr -d '[' | tr -d ']')
printp "DIGEST $IMAGE_DIGEST"
docker rmi $REPO_TAG
printp "IMAGE PUSHED!"

if [ "$PURGE_STRATEGY_NEVER" = true ]
then
  printp "SETTING purge-strategy-never"
  IMAGE_PROPERTY=${IMAGE_PROPERTY:-"docker-dev-local2/cbd/${SERVICE_NAME}/latest"}
  echo "https://$ARTIFACTORY_URL:5000/artifactory/api/storage/$IMAGE_PROPERTY"
  echo "Fetching certificates"
  wget --no-check-certificate https://$ARTIFACTORY_URL:5000/artifactory/cb/carbonblack/certs/vmware-caroot.pem -O /usr/local/share/ca-certificates/vmware-caroot.pem && update-ca-certificates
  echo "Getting image creation date"
  IMAGE_PROPVAL=$(curl -X GET -su "$DOCKER_USER:$DOCKER_PASSWORD" "https://$ARTIFACTORY_URL:5000/artifactory/api/storage/$IMAGE_PROPERTY" | grep '"created" :' | cut -d '"' -f 4)
  [ -z "$IMAGE_PROPVAL" ] && echo "Failed to get creation date" && exit 1
  echo "Setting purge-strategy-never"
  curl -X PUT -su "$DOCKER_USER:$DOCKER_PASSWORD" "https://$ARTIFACTORY_URL:5000/artifactory/api/storage/$IMAGE_PROPERTY?properties=purge-strategy-never=$IMAGE_PROPVAL&recursive=0"
  printp "SET purge-strategy-never"
fi
