#!/usr/bin/env bash
set -e
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
source $(pwd)/config/configuration
source /deployment/deploy/helpers/run_command.sh
source /deployment/deploy/helpers/print_line.sh

if [ ! -z "${AWS_ACCESS_KEY_ID}" ]; then
    aws configure set aws_access_key_id $AWS_ACCESS_KEY_ID --profile $ENV
    aws configure set aws_secret_access_key $AWS_SECRET_ACCESS_KEY --profile $ENV
    aws configure set region $AWS_DEFAULT_REGION --profile $ENV
    aws configure set output json --profile $ENV
fi

export REPO_NAME=${ENV}_${SERVICE_NAME}
export IMAGE_TAG=$(run_deploy_command repo_url $REPO_NAME) || exit 1
export LABEL_TAG_PREFIX="${SERVICE_LABEL}_"
export DEPLOY=${DEPLOY:-false}

/deployment/build/build.sh

if [ "$DEPLOY" = true ]; then
    USER="AWS"
    TOKEN=$(run_deploy_command get_ecr_token) || exit 1
    REGISTRY=$(run_deploy_command get_ecr_registry) || exit 1

    DOCKER_USER="${USER}" \
    DOCKER_PASSWORD="${TOKEN}" \
    DOCKER_REGISTRY="${REGISTRY}" \
    . /deployment/build/push.sh
fi
