#!/usr/bin/env bash
set -e
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
source /deployment/deploy/helpers/aws_keys.sh
source $(pwd)/config/configuration
source /deployment/deploy/helpers/run_command.sh
source /deployment/deploy/helpers/print_line.sh
source /deployment/deploy/helpers/deploy_stages.sh

CLUSTER="$ENV-gateway-ecs"

DEPLOY_SERVICE=${DEPLOY_SERVICE:-false}
DELETE_SERVICE=${DELETE_SERVICE:-false}
export SERVICE_NAME=$( echo $SERVICE_NAME | tr "." _ )
export SERVICE_ENABLED=true


#############################################################################################################
########################################## INITIALIZING TERRAFORM  ##########################################
#############################################################################################################
init_infra

export CREATE_OR_PLAN="CREATING"
if [ ! -z "${PLAN_ONLY}" ]; then
  printh "NO CHANGES WILL BE APPLIED. PLAN ONLY."
  CREATE_OR_PLAN="PLANNING"
fi
#############################################################################################################
##########################################     DEPLOY SERVICE      ##########################################
#############################################################################################################
if [ "$DEPLOY_SERVICE" = true ]; then
    printh "${CREATE_OR_PLAN} X-ENV ${SERVICE_NAME} SERVICE COMMON INFRA"
    create_x_env_common_infra
    printh "${CREATE_OR_PLAN} ${ENV} ${SERVICE_NAME} SERVICE COMMON INFRA"
    create_env_common_infra

    if [ ! -z "${PLAN_ONLY}" ]; then
        update_service
        cleanup_state
        printh "NO CHANGES WERE APPLIED. PLAN ONLY."
        exit 0
    fi

    printh "DEPLOYING ${ENV} ${SERVICE_NAME}_${SERVICE_LABEL} SERVICE"

    SVC_EXISTS=$( run_deploy_command service_exists $CLUSTER ${SERVICE_NAME}_${SERVICE_LABEL} ) || exit 1
    if [ $SVC_EXISTS = "True" ]; then
        printp "${SERVICE_NAME}_${SERVICE_LABEL} EXISTS"
        printp "UPDATING EXISTING SERVICE"
        OLD_REVISION=$( run_deploy_command latest_task_definition ${ENV}_${SERVICE_NAME}_${SERVICE_LABEL} ) || exit 1
	OLD_REVISION_ARN=$( run_deploy_command latest_task_definition_arn ${ENV}_${SERVICE_NAME}_${SERVICE_LABEL} ) || exit 1
    else
        printp "${CREATE_OR_PLAN} NEW SERVICE"
        OLD_REVISION=0
    fi

    build_and_push_image
    printp "KEEP_OLD_TASK_DEFINITION: ${KEEP_OLD_TASK_DEFINITION}"
    printp "ECS_TASK_DEFINITION_TERRAFORM_RESOURCE_NAME: ${ECS_TASK_DEFINITION_TERRAFORM_RESOURCE_NAME}"
    printp "OLD_REVISON: ${OLD_REVISION}"
    if [ ${KEEP_OLD_TASK_DEFINITION} = "True" ] && [ ${OLD_REVISION} != "0" ]; then
	if [ -n ${ECS_TASK_DEFINITION_TERRAFORM_RESOURCE_NAME} ]; then
    		remove_task_definition_from_state ${ECS_TASK_DEFINITION_TERRAFORM_RESOURCE_NAME}
	else
		printp "ECS_TASK_DEFINITION_TERRAFORM_RESOURCE_NAME must be set when KEEP_OLD_TASK_DEFINITION is 'true'"
		exit 1
	fi
    fi
    update_service
    NEW_REVISION=$( run_deploy_command latest_task_definition ${ENV}_${SERVICE_NAME}_${SERVICE_LABEL} ) || exit 1
    TASK_UPDATED=$( run_deploy_command task_definition_updated ${ENV}_${SERVICE_NAME}_${SERVICE_LABEL} ${OLD_REVISION} ) || exit 1
    if [ ${TASK_UPDATED} = "True" ]; then
        printp "NEW TASK DEFINITION WAS CREATED"
        print "TASK REVISION $NEW_REVISION IS BEING PROVISIONED"
        wait_for_tasks_to_run $NEW_REVISION $INSTANCES
    else
        printp "NO NEW TASK DEFINITION WAS CREATED"
        print "TASK REVISION $NEW_REVISION WILL CONTINUE TO RUN"
	if [ ${KEEP_OLD_TASK_DEFINITION} = "True" ] && [ ${OLD_REVISION} != "0" ]; then
            if [ -n ${ECS_TASK_DEFINITION_TERRAFORM_RESOURCE_NAME} ]; then
		return_task_definition_to_state ${ECS_TASK_DEFINITION_TERRAFORM_RESOURCE_NAME} ${OLD_REVISION_ARN}
            else
                printp "ECS_TASK_DEFINITION_TERRAFORM_RESOURCE_NAME must be set when KEEP_OLD_TASK_DEFINITION is 'true'"
                exit 1
            fi
	fi
    fi

    printp "${SERVICE_NAME}_${SERVICE_LABEL} IS DEPLOYED!"
fi

#############################################################################################################
##########################################     DELETE SERVICE      ##########################################
#############################################################################################################
if [ "$DELETE_SERVICE" = true ]; then
    printh "DELETING ${ENV} ${SERVICE_NAME}_${SERVICE_LABEL} SERVICE"
    delete_service
    printp "${ENV} ${SERVICE_NAME}_${SERVICE_LABEL} IS DELETED!"
fi

#############################################################################################################
##########################################     DELETE ENV-COMMON      ##########################################
#############################################################################################################
if [ "$DELETE_ENV_COMMON" = true ]; then
    printh "DELETING ${ENV} ${SERVICE_NAME} ENV COMMON INFRA"
    delete_env_common
    printp "${ENV} ${SERVICE_NAME} ENV COMMON INFRA IS DELETED!"
fi

cleanup_state

if [ ! -z "${PLAN_ONLY}" ]; then
  printh "NO CHANGES WERE APPLIED. PLAN ONLY."
fi
